==> haskell-network-simple-0.4.5-178-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-simple
version:              0.4.5
visibility:           public
id:                   network-simple-0.4.5-HyX1d64ufp78K4Y5FoQAW
key:                  network-simple-0.4.5-HyX1d64ufp78K4Y5FoQAW
license:              BSD-3-Clause
copyright:            Copyright (c) Renzo Carbonara 2013-2019
maintainer:           renλren.zone
author:               Renzo Carbonara
homepage:             https://github.com/k0001/network-simple
synopsis:             Simple network sockets usage patterns.
description:
    This module exports functions that abstract simple network socket
    usage patterns.

    See the @changelog.md@ file in the source distribution to learn about any
    important changes between versions.

category:             Network
abi:                  dafc58a390123bf370a2d8ec69398802
exposed:              True
exposed-modules:      Network.Simple.TCP
hidden-modules:       Network.Simple.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-simple-0.4.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-simple-0.4.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-simple-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-simple
hs-libraries:         HSnetwork-simple-0.4.5-HyX1d64ufp78K4Y5FoQAW
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-1eoJcyQnoY08famP5jSKP3
    network-bsd-2.8.1.0-2Idz5QPbLS37FO0cfIbqZZ
    safe-exceptions-0.1.7.4-8BYhzOxxHHwAOn86TOr3v5
    socks-0.6.1-3m57zMehOnIBWCy6CUOAFy transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-network-simple/html/network-simple.haddock

haddock-html:         /usr/share/doc/haskell-network-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-simple-0.4.5-179-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-simple
version:              0.4.5
visibility:           public
id:                   network-simple-0.4.5-Lk7zxjzq5a89bgc5bUdFoa
key:                  network-simple-0.4.5-Lk7zxjzq5a89bgc5bUdFoa
license:              BSD-3-Clause
copyright:            Copyright (c) Renzo Carbonara 2013-2019
maintainer:           renλren.zone
author:               Renzo Carbonara
homepage:             https://github.com/k0001/network-simple
synopsis:             Simple network sockets usage patterns.
description:
    This module exports functions that abstract simple network socket
    usage patterns.

    See the @changelog.md@ file in the source distribution to learn about any
    important changes between versions.

category:             Network
abi:                  37b9be8da5bb066a7c13e2d19f5753aa
exposed:              True
exposed-modules:      Network.Simple.TCP
hidden-modules:       Network.Simple.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-simple-0.4.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-simple-0.4.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-simple-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-simple
hs-libraries:         HSnetwork-simple-0.4.5-Lk7zxjzq5a89bgc5bUdFoa
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-KCu1LDB4kGQHeeCsiSLoOZ
    network-bsd-2.8.1.0-EQn85K5aNj6GARKlD20Ibk
    safe-exceptions-0.1.7.4-FdcreoZ4FzWCuMODFvBw2l
    socks-0.6.1-1JWe4RwzcvbFmOelmU10uV transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-network-simple/html/network-simple.haddock

haddock-html:         /usr/share/doc/haskell-network-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
